Description Usage Arguments Value
Individual initializer.
1 2 3 | initIndividual(instance, current.time = 0, init.tours = integer(),
n.vehicles = 1L, template.ind = NULL,
init.distribution = "binomial")
|
instance |
[ |
current.time |
[ |
init.tours |
[ |
n.vehicles |
[ |
template.ind |
[ |
init.distribution |
[ |
[VRPIndividual] List with following components:
bBinary vector of length |V| - 2. b[i] is 1, if customer i is active, i.e., in tour.
tPermutation vector.
pVector of mutation probablities. I.e., p[i] is the probability to flip b[i]. p[i] is zero if customer i is already fixed or not yet released.
itBinary vector of length |V| - 2. it[i] is 1 if and only if customer i is in initial tour.
integer(1)Number of mandatory customers.
integerIDs/positions of dynamic customers which already requested serving.
integer(1)Number of active dynamic customers i (i.e., b[i] = 1)
integer(1)Number of available, but not active dynamic customers i (i.e., b[i] = 0)
integerFixed tour part, i.e., sequence of nodes already visited.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.